ArrayValue

Type Alias ArrayValue 

pub type ArrayValue = Vec<Value>;
The type used to represent the scalars inside an array. An array can only store scalar values of the same type.

Aliased Type

pub struct ArrayValue { /* private fields */ }