Module value

Module value 

A dynamically-typed representation of libconfig data

This module provides the Value enum which represents any valid libconfig value. It can be used when you don’t know the structure of the data at compile time.

Structs

Config
A libconfig document that tracks top-level formatting.

Enums

Value
A dynamically-typed value that can represent any libconfig data

Functions

from_value
Convert a Value to a specific type T

Type Aliases

Map
A map of string keys to Values, representing a libconfig group Uses IndexMap to preserve insertion order